#!/usr/bin/python

"""
Connects to my D-Link DSL-2640R, grabs bytes transmitted/received
and the line speed and writes them into a file. Called by cron
to set the interval in the file.

Author: Robin Rawson-Tetley
Date:   1st March, 2010
"""

import sys, telnetlib, datetime

# The router's host/ip address
HOST = "router"
OUTDIR = "/home/robin"
PASS = "password"
TRAFFIC = "show channel disp 0"
LINESPEED = "wan adsl chandata"

# Connect and log in
tn = telnetlib.Telnet(HOST)
tn.read_until("Password: ")
tn.write(PASS + "\n")

# Get the traffic stats
tn.read_until("D-Link> ")
tn.write(TRAFFIC + "\n")
statstring = tn.read_until("D-Link> ")

# Get the line speed
tn.write(LINESPEED + "\n")
linestring = tn.read_until("D-Link> ")

# Parse received bytes
inr = statstring.find("inOctet")
inr = statstring.find("=", inr) + 1
recbytes = int(statstring[inr:statstring.find(",", inr)])

# Parse sent bytes
outr = statstring.find("outOctet")
outr = statstring.find("=", outr) + 1
sentbytes = int(statstring[outr:statstring.find(",", outr)])

# Parse linespeed
ld = linestring.find(" kbps") - 4
linedown = int(linestring[ld:ld+4])
lu = linestring.find(" kbps")
lu = linestring.find(" kbps", lu + 1)
lu = linestring.find(" kbps", lu + 1) - 4
lineup = int(linestring[lu:lu + 4])

# Get the last up and down values so we can diff
lastup = 0
lastdown = 0
try:
    f = open(OUTDIR + "/lastvalues.txt", "r")
    lines = f.readlines()
    f.close()
    lastup = int(lines[0])
    lastdown = int(lines[1])
except:
    lastup = 0
    lastdown = 0

print "lastup: %d, lastdown: %d" % ( lastup, lastdown )

# Write the new values
lvf = open(OUTDIR + "/lastvalues.txt", "w")
lvf.write( "%d\n%d\n" % ( sentbytes, recbytes ))
lvf.close()

# If we have a higher downcount, then the router has been reset -
# leave the recbytes as the reading
if lastdown < recbytes:
    recbytes = recbytes - lastdown
if lastup < sentbytes:
    sentbytes = sentbytes - lastup

# Grab current data and time
d = datetime.datetime.today()
timenow = d.strftime("%H:%M:%S")
datenow = d.strftime("%Y-%m-%d")

# Ok, let's write our data file
dataline = "%s\t%s\t%d\t%d\t%d\t%d\n" % ( datenow, timenow, recbytes, sentbytes, linedown, lineup )
df = open(OUTDIR + "/bandwidth.txt", "a")
df.write(dataline)
df.close()

print "Received: %d, Sent: %d, Up: %d, Down: %d" % ( recbytes, sentbytes, lineup, linedown)
