#!/usr/bin/python

"""
Simple webpage that calculates and shows bandwidth usage for
the current month and year
"""

# The tab-delimited file containing usage figures in form:
# date time bytesdown bytesup speeddown speedup
BANDWIDTH="bandwidth.txt"
# Number of pixels to use per megabyte for graphing
PIXELS_PER_MB=1

import datetime,time

# Read the file
f = open(BANDWIDTH, "r")
lines = f.readlines()
f.close()

# Scan the lines and add up totals
totalyeardown = 0
totalyearup = 0
totalmonthdown = 0
totalmonthup = 0
days = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
today = datetime.datetime.now()
avg = 0
avgnum = 0

# Add up monthly, yearly and daily totals
for l in lines:
    bits = l.split("\t")
    d = time.strptime(bits[0], "%Y-%m-%d")
    year = d[0]
    month = d[1]
    day = d[2]

    # Up the totals
    if month == today.month and year == today.year:
        totalmonthdown += int(bits[2])
        totalmonthup += int(bits[3])
    if year == today.year:
        totalyeardown += int(bits[2])
        totalyearup += int(bits[3])
    days[day - 1] += int(bits[2])

# Calculate average for each day this month
for d in days:
    if d > 0:
        avg += d
        avgnum += 1
avg = avg / avgnum

print "Content-Type: text/html\n\n"

print """
<html>
<head>
<title>Bandwidth Usage</title>
<style type="text/css"> 
<!--
* {
    font-family: sans-serif;
}
p.copyright {
    font-size: 8pt;
    text-align: right;
    background-color: #fff499;
    border: 1px solid #e0e0e0;
    padding: 6px;
}
td.value {
    background-image: url(gridline58.gif);
    background-repeat: repeat-x;
    background-position: left top;
    border-left: 1px solid #e5e5e5;
    border-right: 1px solid #e5e5e5;
    padding:0;
    border-bottom: none;
    background-color:transparent;
}
td {
    padding: 4px 6px;
    border-bottom:1px solid #e5e5e5;
    border-left:1px solid #e5e5e5;
    background-color:#fff;
    font-size: 8pt;
}
body {
    font-family: Verdana, Arial, Helvetica, sans-serif;
    font-size: 80%%;
}
td.value img {
    vertical-align: middle;
    margin: 5px 5px 5px 0;
}

td.value {
    font-weight: bold;
    font-size: 8pt;
}
th {
    text-align: left;
    vertical-align:top;
}
td.last {
    border-bottom:1px solid #e5e5e5;
}
td.first {
    border-top:1px solid #e5e5e5;
}
.auraltext
{
   position: absolute;
   font-size: 0;
   left: -1000px;
}
table {
    background-image:url(bg_fade.png);
    background-repeat:repeat-x;
    background-position:left top;
    width: 33em;
}
caption {
    font-size:90%%;
    font-style:italic;
}
-->
</style> 
</head>
<body>
<p class="copyright">2640Rcap: Copyright(c)2010, R. Rawson-Tetley. This program is <a href="http://www.gnu.org/copyleft/gpl.html">GPL</a></p>
<h1>Bandwidth Used</h1>
<table>
<tr>
<td>Downloaded in %s:</td><td class="value">%d MB (%0.2f GB)</td>
</tr><tr>
<td>Uploaded in %s:</td><td class="value">%d MB (%0.2f GB)</td>
</tr><tr>
<td>Average downloaded per day :</td><td class="value">%d MB</td>
</tr><tr>
<td>Downloaded in %s:</td><td class="value">%d MB (%0.2f GB)</td>
</tr><tr>
<td>Uploaded in %s:</td><td class="value">%d MB (%0.2f GB)</td>
</tr><table>
<h2>%s</h2>
""" % (today.strftime("%B %Y"), 
    (totalmonthdown / 1024 / 1024), 
    (totalmonthdown / 1024 / 1024 / 1024.0),
    today.strftime("%B %Y"), 
    (totalmonthup / 1024 / 1024), 
    (totalmonthup / 1024 / 1024 / 1024.0),
    (avg / 1024 / 1024), 
    today.strftime("%Y"),
    (totalyeardown / 1024 / 1024),
    (totalyeardown / 1024 / 1024 / 1024.0),
    today.strftime("%Y"),
    (totalyearup / 1024 / 1024), 
    (totalyearup / 1024 / 1024 / 1024.0),
    today.strftime("%B %Y") )

# Generate usage graph for each day. Use one pixel per MB
print """
<table cellspacing="0" cellpadding="0">
      <tr> 
        <th scope="col"><span class="auraltext">Day</span> </th> 
        <th scope="col"><span class="auraltext">Download bandwidth used (MB)</span> </th> 
      </tr>
"""

for i in range(0, len(days)):
    print """
      <tr> 
        <td>%d</td> 
        <td class="value"><img src="bar.png" alt="" width="%d" height="16" />%dMB</td> 
      </tr> 
    """ % (i + 1, (days[i] / 1024 / 1024) / PIXELS_PER_MB, days[i] / 1024 / 1024)

print """
</table>
</body>
</html>
"""
